#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hOpenPGP
version:              2.10.1
visibility:           public
id:                   hOpenPGP-2.10.1-LVQhlvIasO65Ay8dH9zbwQ
key:                  hOpenPGP-2.10.1-LVQhlvIasO65Ay8dH9zbwQ
license:              MIT
copyright:            2012-2025  Clint Adams
maintainer:           Clint Adams <clint@debian.org>
author:               Clint Adams
homepage:             https://salsa.debian.org/clint/hOpenPGP
synopsis:             native Haskell implementation of OpenPGP (RFC4880)
description:
    native Haskell implementation of OpenPGP (RFC4880), plus Camellia (RFC5581), plus ECC (RFC6637)

category:             Codec, Data
abi:                  c835865704d9feb5151d5e010490df21
exposed:              True
exposed-modules:
    Codec.Encryption.OpenPGP.CFB Codec.Encryption.OpenPGP.Compression
    Codec.Encryption.OpenPGP.Expirations
    Codec.Encryption.OpenPGP.Fingerprint
    Codec.Encryption.OpenPGP.KeyInfo
    Codec.Encryption.OpenPGP.KeySelection
    Codec.Encryption.OpenPGP.KeyringParser
    Codec.Encryption.OpenPGP.Ontology Codec.Encryption.OpenPGP.S2K
    Codec.Encryption.OpenPGP.SecretKey
    Codec.Encryption.OpenPGP.Serialize
    Codec.Encryption.OpenPGP.SignatureQualities
    Codec.Encryption.OpenPGP.Signatures Codec.Encryption.OpenPGP.Types
    Codec.Encryption.OpenPGP.Version Data.Conduit.OpenPGP.Compression
    Data.Conduit.OpenPGP.Decrypt Data.Conduit.OpenPGP.Filter
    Data.Conduit.OpenPGP.Keyring Data.Conduit.OpenPGP.Keyring.Instances
    Data.Conduit.OpenPGP.Verify

hidden-modules:
    Codec.Encryption.OpenPGP.Internal
    Codec.Encryption.OpenPGP.Internal.CryptoCipherTypes
    Codec.Encryption.OpenPGP.Internal.Crypton
    Codec.Encryption.OpenPGP.Internal.HOBlockCipher
    Codec.Encryption.OpenPGP.Types.Internal.Base
    Codec.Encryption.OpenPGP.Types.Internal.CryptonNewtypes
    Codec.Encryption.OpenPGP.Types.Internal.PKITypes
    Codec.Encryption.OpenPGP.Types.Internal.PacketClass
    Codec.Encryption.OpenPGP.Types.Internal.Pkt
    Codec.Encryption.OpenPGP.Types.Internal.PrettyUtils
    Codec.Encryption.OpenPGP.Types.Internal.TK
    Codec.Encryption.OpenPGP.BlockCipher
    Codec.Encryption.OpenPGP.SerializeForSigs Paths_hOpenPGP

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hOpenPGP-2.10.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hOpenPGP-2.10.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hOpenPGP-2.10.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hopenpgp
hs-libraries:         HShOpenPGP-2.10.1-LVQhlvIasO65Ay8dH9zbwQ
depends:
    aeson-2.2.2.0-3pjCpj5XtaHAHmzSwnt06z
    asn1-encoding-0.9.6-BiuQkUe1jGtAiFYcd1gh8T
    attoparsec-0.14.4-8xTfRBafHfnLSxW1Zd3VTX base-4.18.2.1
    base16-bytestring-1.0.2.0-KkKTvweYtUjAEl7m2QLWFY
    bifunctors-5.6.3-7bjHyYyfYBQARUyvp7mikv binary-0.8.9.1
    binary-conduit-1.3.1-6glcJjTCFe2IKEyxZewj4a bytestring-0.11.5.3
    bz2-1.0.1.2-1WHkrmsl0K4EjvuVfJFwkv
    conduit-1.3.6.1-A5CFvWaedHyBbFpBELr7ED
    conduit-extra-1.3.8-4LNkvIzwsWe54JJPbCmwjx containers-0.6.7
    crypto-cipher-types-0.0.9-KR6SDml7aC01N7sg8RBO5C
    crypton-1.0.5-ISaCEA7WOGuAiZSS5ibrwY
    errors-2.3.0-6s2rOZrEfPcDfQQIbVMJby
    hashable-1.4.7.0-KYRxVQLzygQHnYjqLKyJPN
    incremental-parser-0.5.1-D5w3owCUYdfIQMZ4fMlErM
    ixset-typed-0.5.1.1-980GugVmO1dFThkILJFO4t
    lens-5.3.5-JKPJsUIkx0YEZ4W3JntdKw
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    monad-loops-0.4.3-LG7facWXNYz9W52syv7lz8
    nettle-0.3.1.1-A0M1aIGFyuW7FI1LGOgmW3
    network-uri-2.6.4.2-2pvBC2E3r3ZG7itzgqfKfv
    openpgp-asciiarmor-1.0-IDGcqDZWdifENXn9aXxH3R
    prettyprinter-1.7.2-6Ih5s8mp5Rq22RoHimn1zv
    resourcet-1.3.0-G1Jndw6mtoEGFSzuHCFgbA
    split-0.2.5-3KQHz3VjCt4O3lCLzOFzl text-2.0.2 time-1.12.2
    time-locale-compat-0.1.1.5-8XUEctZKps57K6Zw5siYoh
    transformers-0.6.1.0 unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.21-5Z67IC6H036CG8YRUzTmvt
    zlib-0.7.1.0-HgVwWopIY16LHV8ByRCkHf

haddock-interfaces:   /usr/share/doc/haskell-hopenpgp/html/hOpenPGP.haddock
haddock-html:         /usr/share/doc/haskell-hopenpgp/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

